<?php

declare(strict_types=1);

namespace Dedi\SyliusTaxonTypePlugin\Request;

use Sylius\Bundle\ResourceBundle\Controller\RequestConfiguration;
use Sylius\Bundle\ResourceBundle\Controller\RequestConfigurationFactoryInterface;
use Sylius\Component\Resource\Metadata\MetadataInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RequestStack;

final class RequestConfigurationFactory implements RequestConfigurationFactoryInterface
{
    private RequestConfigurationFactoryInterface $decoratedFactory;

    private RequestStack $requestStack;

    public function __construct(
        RequestConfigurationFactoryInterface $decoratedFactory,
        RequestStack $requestStack
    ) {
        $this->decoratedFactory = $decoratedFactory;
        $this->requestStack = $requestStack;
    }

    public function create(MetadataInterface $metadata, Request $request): RequestConfiguration
    {
        $parameters = $request->attributes->get('_sylius', []);

        if (null === $this->requestStack->getParentRequest()
            && array_key_exists('vars', $parameters)
            && array_key_exists('factory', $parameters['vars'])
        ) {
            $parameters['factory'] = $parameters['vars']['factory'];
            $request->attributes->set('_sylius', $parameters);
        }

        return $this->decoratedFactory->create($metadata, $request);
    }
}
